@@ -1,5 +1,5 @@
 // File_AvsV - Info for AVS Video files
-// Copyright (C) 2006-2009 Jerome Martinez, Zen@MediaArea.net
+// Copyright (C) 2006-2011 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License as published by
@@ -8,7 +8,7 @@
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
@@ -293,7 +293,6 @@ bool File_AvsV::Synched_Test()
 void File_AvsV::Synched_Init()
 {
     //Count of a Packets
-    Frame_Count=0;
     progressive_frame_Count=0;
     Interlaced_Top=0;
     Interlaced_Bottom=0;
@@ -418,13 +417,13 @@ void File_AvsV::Data_Parse()
         default:
             if (Element_Code>=0x00
              && Element_Code<=0xAF) slice();
-            else if (Element_Code==0xE0 && Element_Size>=2 && CC2(Buffer+Buffer_Offset)==0x0000)
-            {
-                Trusted=0; //This is surely an extract from MPEG-TS
-                Trusted_IsNot("Unattended element");
-            }
             else
+            {
+                if (Frame_Count==0 && Buffer_TotalBytes>Buffer_TotalBytes_FirstSynched_Max)
+                    Trusted=0;
                 Trusted_IsNot("Unattended element");
+
+            }
     }
 
     if (File_Offset+Buffer_Offset+Element_Size==File_Size && Frame_Count>0 && Count_Get(Stream_Video)==0) //Finalize frames in case of there are less than Frame_Count_Valid frames
